package com.fs.store.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.fs.store.domain.FsUser;
import com.fs.store.domain.FsUserOnlineState;

/**
 * 用户上线情况Mapper接口
 *
 * @author fs
 * @date 2025-06-30
 */
public interface FsUserOnlineStateMapper extends BaseMapper<FsUserOnlineState>{
    /**
     * 查询用户上线情况
     *
     * @param userId 用户上线情况主键
     * @return 用户上线情况
     */
    FsUserOnlineState selectFsUserOnlineStateById(Long userId);

    /**
     * 查询用户上线情况列表
     *
     * @param fsUserOnlineState 用户上线情况
     * @return 用户上线情况集合
     */
    List<FsUserOnlineState> selectFsUserOnlineStateList(FsUserOnlineState fsUserOnlineState);

    /**
     * 新增用户上线情况
     *
     * @param fsUserOnlineState 用户上线情况
     * @return 结果
     */
    int insertFsUserOnlineState(FsUserOnlineState fsUserOnlineState);

    /**
     * 修改用户上线情况
     *
     * @param fsUserOnlineState 用户上线情况
     * @return 结果
     */
    int updateFsUserOnlineState(FsUserOnlineState fsUserOnlineState);

    /**
     * 删除用户上线情况
     *
     * @param userId 用户上线情况主键
     * @return 结果
     */
    int deleteFsUserOnlineStateById(Long userId);

    /**
     * 批量删除用户上线情况
     *
     * @param userIds 需要删除的数据主键集合
     * @return 结果
     */
    int deleteFsUserOnlineStateByIds(Long[] userIds);

    /**
     * 查询没有看课记录的用户
     * @return
     */
    List<FsUserOnlineState> selectUserNotOnline();

    /**
     * 查询短时间已经有且仅有一条看课记录的用户（查询的时间需要大于等于定时任务的时间）
     * @return
     */
    List<FsUser> selectExistWatchLogUser();

}
